﻿/*
 * Chronometre.cpp
 * This file is part of ChronoCheckMate
 *
 * Copyright (C) 2010 - François Drouhard
 *
 * ChronoCheckMate is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * ChronoCheckMate is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ChronoCheckMate; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, 
 * Boston, MA  02110-1301  USA
 */
 
#include "Chronometre.h"
#include <QTimer>
#include <QtWidgets>
#include <QLabel>
#include <QObject>
#include <QHBoxLayout>
#include <QDebug>
#include <QFont>
#include <QTime>

Chronometre::Chronometre (const QString & nom , int tempsDepart, QWidget * parent = nullptr) :
    QGroupBox (nom , parent),
    ms(1000*60*tempsDepart),
    msTempsDepart(1000*60*tempsDepart)
{
    setFlat(false);

    temps = new QTime (0,0,0,0);
    QFont font("Arial" , 22 , 5);

    ecranTemps = new QLabel (temps->toString("hh:mm::ss:zzz"));
    ecranTemps->setFont(font);

    ecranLayout = new QHBoxLayout;
    ecranLayout->addSpacing(40);
    ecranLayout->addWidget(ecranTemps);
    ecranLayout->addSpacing(40);


    setLayout (ecranLayout);
	
    affichage();
    timer = new QTimer  (this);
	timer->setInterval (10);
	QObject::connect (timer , SIGNAL (timeout() ) , this , SLOT (refresh()));
}

void Chronometre::modifierNomJoueur(QString joueur) {
    setTitle(joueur);
}

void Chronometre::definirTemps(int tempsDepart) {
    msTempsDepart = tempsDepart*60*1000;
}

void Chronometre::refresh () {
    ms -= 10;
    if (ms <= 0) {
        emit fin();
    }
	affichage ();
}

void Chronometre::start () {
	timer->start ();
}

void Chronometre::stop () {
    timer->stop();
}


void Chronometre::affichage () {
    QString chaineTemps = temps->addMSecs(ms).toString("hh:mm:ss:zzz");
    ecranTemps->setText(chaineTemps);
}

void Chronometre::reinit () {
	if (timer->isActive()) {
		timer->stop();
	}
    ms  = msTempsDepart;
	affichage();
}

void Chronometre::basculer () {
	if (timer->isActive()) {
		timer->stop();
	}
	else {
		timer->start ();
	}

}
